<!DOCTYPE html>
<html>
    <head>
        <title>Error 404</title>
        <link rel="stylesheet" href="{{ url_for('static', filename = 'pagestyle.css') }}">
    </head>

    <div class="content">
        <p><h2>Error</h2></ br> You have entered a wrong location. Please try again.</p>
        <script src="https://unpkg.com/@lottiefiles/lottie-player@latest/dist/lottie-player.js"></script>
        <lottie-player src="https://assets1.lottiefiles.com/temp/lf20_USCruP.json"  background="transparent"  speed="1"  style="width: 300px; height: 300px;"  loop autoplay></lottie-player>
        <a id="singlebutton" name="singlebutton" class="myButton" href={{url}} ;>Go back</a>
    </div>
            
    </body>
</html>
