<!DOCTYPE html>
<html>

<head>
  <title>Complete</title>
  <link rel="stylesheet" href="{{ url_for('static', filename = 'pagestyle.css') }}">
</head>

  <body class="content">
    <h1>File Cleaning Completed</h1>
    <h3>Here is the report.</h3>
    <p>
      {% for key,value in res.items() %} 
        {% if 'Others' in key %}
        {% else %}
        {{value}}&nbsp; &nbsp; &nbsp; moved to {{key}}<br>
        {%endif %}
      {% endfor %}

      {% if res['Others(Not_moved)'] in (None, 0, '0') %} 
        <span>0</span>
      {% else %}
        {{res['Others(Not_moved)']}}
      {%endif%}
      &nbsp; &nbsp; &nbsp;items are not moved<br>
    </p>
    <br><br>
    <a class="myButton" href={{url+'/openlocation'}}>Check</a> the folder, &nbsp; &nbsp; &nbsp;
    <a class="myButton" href={{url+'/changelocation'}}>Clean another Folder</a>
    <script src="https://unpkg.com/@lottiefiles/lottie-player@latest/dist/lottie-player.js"></script>
    <lottie-player src="https://assets7.lottiefiles.com/packages/lf20_Mt38fp.json"  background="transparent"  speed="1"  style="width: 350px; height: 350px;"    autoplay></lottie-player>
    <br><br>
    {% extends "base.html" %}
    
  </body>

</html>
